@@ -1,21 +1,22 @@
 ;;; matlab-complete.el --- Simple completion tool for matlab-mode -*- lexical-binding: t -*-
 
-;; Copyright (C) 2024 Free Software Foundation, Inc.
 
 ;; Author: Eric Ludlam <zappo@gnu.org>
+
+;; Copyright (C) 2019-2024 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
 ;; published by the Free Software Foundation, either version 3 of the
 ;; License, or (at your option) any later version.
-
+;;
 ;; This program is distributed in the hope that it will be useful, but
 ;; WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ;; General Public License for more details.
-
+;;
 ;; You should have received a copy of the GNU General Public License
-;; along with this program.  If not, see https://www.gnu.org/licenses/.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 ;;
@@ -33,6 +34,7 @@
 (require 'cl-macs)
 (require 'matlab)
 (require 'matlab-shell)
+(require 'matlab--shell-bridge)
 
 (defun matlab-uniquify-list (lst)
   "Return a list that is a subset of LST where all elements are unique."
@@ -401,7 +403,7 @@ If NEXT then the next patch from the list is used."
 (defun matlab-property-completions (prefix &optional next)
   "Return PREFIX matching elements for property names in strings.
 If NEXT then the next property from the list is used."
-  (let ((f (matlab-function-called-at-point))
+  (let ((f (matlab--function-called-at-point))
 	(lst matlab-property-lists)
 	(foundlst nil)
 	(expandto nil))
