@@ -1,8 +1,8 @@
 ;;; matlab-syntax.el --- Manage MATLAB syntax tables and buffer parsing -*- lexical-binding: t -*-
 
-;; Copyright (C) 2024 Free Software Foundation, Inc.
+;; Author:  <eludlam@mathworks.com>, <john.ciolfi.32@gmail.com>
 
-;; Author:  <eludlam@mathworks.com>
+;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -15,12 +15,12 @@
 ;; General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with this program.  If not, see https://www.gnu.org/licenses/.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 ;;
 ;; Manage syntax handling for `matlab-mode'.
-;; Matlab's syntax for comments and strings can't be handled by a standard
+;; MATLAB's syntax for comments and strings can't be handled by a standard
 ;; Emacs syntax table.  This code handles the syntax table, and special
 ;; scanning needed to augment a buffer's syntax for all our special cases.
 ;;
@@ -28,12 +28,24 @@
 ;; block scanning, and the line.
 
 (require 'matlab-compat)
+(require 'matlab-sections)
 
 ;;; Code:
-(defvar matlab-syntax-support-command-dual t
+
+(defface matlab-comment-heading-face
+  '((t :inherit font-lock-comment-face
+       :overline t
+       :bold t))
+  "Face for \"%% code section\" headings when NOT in matlab-sections-minor-mode.
+
+Using \"%% code section\" heading in non-script files, for example,
+function's, classdef's, etc.  is useful to demarcate concepts and this face
+is used for that purpose."
+  :group 'matlab-sections)
+
+(defvar-local matlab-syntax-support-command-dual t
   "Non-nil means to support command dual for indenting and syntax highlight.
 Does not work well in classes with properties with datatypes.")
-(make-variable-buffer-local 'matlab-syntax-support-command-dual)
 (put 'matlab-syntax-support-command-dual 'safe-local-variable #'booleanp)
 
 
@@ -58,7 +70,7 @@ Does not work well in classes with properties with datatypes.")
     ;;   Unterminated Char V: ' text
     (modify-syntax-entry ?'  "\"" st)
     (modify-syntax-entry ?\" "\"" st)
-    
+
     ;; Words and Symbols:
     (modify-syntax-entry ?_  "_" st)
 
@@ -83,7 +95,7 @@ Does not work well in classes with properties with datatypes.")
     (modify-syntax-entry ?\]  ")[" st)
     ;;(modify-syntax-entry ?{  "(}" st) - Handled as part of comments
     ;;(modify-syntax-entry ?}  "){" st)
-    
+
     st)
   "MATLAB syntax table.")
 
@@ -96,18 +108,10 @@ Does not work well in classes with properties with datatypes.")
 
 (defmacro matlab-navigation-syntax (&rest forms)
   "Set the current environment for syntax-navigation and execute FORMS."
-  (declare (indent 0))
-  (list 'let '((oldsyntax (syntax-table))
-	       (case-fold-search nil))
-	(list 'unwind-protect
-	      (list 'progn
-		    '(set-syntax-table matlab-navigation-syntax-table)
-		    (cons 'progn forms))
-	      '(set-syntax-table oldsyntax))))
-
-(add-hook 'edebug-setup-hook
-	  (lambda ()
-	    (def-edebug-spec matlab-navigation-syntax def-body)))
+  (declare (indent 0) (debug t))
+  `(let ((case-fold-search nil))
+     (with-syntax-table matlab-navigation-syntax-table
+       ,@forms)))
 
 ;;; Buffer Scanning for Syntax Table Augmentation
 ;;
@@ -131,9 +135,8 @@ Does not work well in classes with properties with datatypes.")
 
 (defmacro matlab--syntax-symbol (symbol syntax doc)
   "Create a new SYMBOL with DOC used as a text property category with SYNTAX."
-  (declare (indent defun))
-  `(progn (defvar ,symbol ,syntax ,doc)
-	  (set ',symbol ,syntax) ;; So you can re-eval it.
+  (declare (indent defvar) (debug (sexp form sexp)) (doc-string 3))
+  `(progn (defconst ,symbol ,syntax ,doc)
 	  (put ',symbol 'syntax-table ,symbol)
 	  ))
 
@@ -178,7 +181,7 @@ and `matlab--scan-line-for-unterminated-string' for specific details."
 	    (end-of-line)
 	    (matlab--put-char-category (point) 'matlab--command-dual-syntax)
 	    ))
-	
+
 	;; Multiple ellipsis can be on a line.  Find them all
 	(beginning-of-line)
 	(while (matlab--scan-line-for-ellipsis)
@@ -324,11 +327,19 @@ Called when comments found in `matlab--scan-line-for-unterminated-string'."
 	    (t
 	     'font-lock-string-face))
 
-    ;; Not a string, must be a comment.  Check to see if it is a
-    ;; cellbreak comment.
+    ;; Not a string, must be a comment. Pick type of comment face to use.
     (cond ((and (< (nth 8 pps) (point-max))
-		(= (char-after (1+ (nth 8 pps))) ?\%))
-	   'matlab-sections-section-break-face)
+                (= (char-after (1+ (nth 8 pps))) ?\%)) ;; looking-at "%%"?
+           ;; Now see if we have a valid section start comment
+           (if (and (boundp 'matlab-sections-minor-mode) matlab-sections-minor-mode
+                    (save-excursion
+                      (save-restriction
+                        (widen)
+                        (goto-char (nth 8 pps))
+                        (beginning-of-line)
+                        (looking-at matlab-sections-section-break-regexp))))
+               'matlab-sections-section-break-face
+             'matlab-comment-heading-face))
 	  ((and (< (nth 8 pps) (point-max))
 		(= (char-after (1+ (nth 8 pps))) ?\#))
 	   'matlab-pragma-face)
@@ -350,29 +361,22 @@ Called when comments found in `matlab--scan-line-for-unterminated-string'."
   "Integrate our syntax handling into a running `matlab-mode' buffer.
 Safe to use in `matlab-mode-hook'."
   ;; Syntax Table support
+  ;; FIXME: The conventional name is `matlab-mode-syntax-table'!
   (set-syntax-table matlab-syntax-table)
-  (make-local-variable 'syntax-propertize-function)
-  (setq syntax-propertize-function 'matlab--syntax-propertize)
+  (setq-local syntax-propertize-function #'matlab--syntax-propertize)
   ;; Comment handlers
-  (make-local-variable 'comment-start)
-  (make-local-variable 'comment-end)
-  (make-local-variable 'comment-start-skip)
-  (make-local-variable 'page-delimiter)
-  (setq comment-start "%"
-	comment-end   ""
-        comment-start-skip "%\\s-+"
-	page-delimiter "^\\(\f\\|%%\\(\\s-\\|\n\\)\\)")
+  (setq-local comment-start "%")
+  (setq-local comment-end   "")
+  (setq-local comment-start-skip "%\\s-+")
+  (setq-local page-delimiter "^\\(\f\\|%%\\(\\s-\\|\n\\)\\)")
   ;; Other special regexps handling different kinds of syntax.
-  (make-local-variable 'paragraph-start)
-  (setq paragraph-start (concat "^$\\|" page-delimiter))
-  (make-local-variable 'paragraph-separate)
-  (setq paragraph-separate paragraph-start)
-  (make-local-variable 'paragraph-ignore-fill-prefix)
-  (setq paragraph-ignore-fill-prefix t)
-  
+  (setq-local paragraph-start (concat "^$\\|" page-delimiter))
+  (setq-local paragraph-separate paragraph-start)
+  (setq-local paragraph-ignore-fill-prefix t)
+
   ;; Font lock
-  (make-local-variable 'font-lock-syntactic-face-function)
-  (setq font-lock-syntactic-face-function 'matlab--font-lock-syntactic-face)
+  (setq-local font-lock-syntactic-face-function
+              #'matlab--font-lock-syntactic-face)
   )
 
 ;;; Syntax Testing for Strings and Comments
@@ -430,7 +434,7 @@ bounds of the string or comment the cursor is in"
 			   'comment
 			 'ellipsis))
 		      (t nil)))
-	  
+
 	  ;; compute the bounds
 	  (when (and syntax bounds-sym)
 	    (if (memq syntax '(charvector string))
@@ -452,7 +456,7 @@ Optional ALL-COMMENTS if t, move to first."
     (prog1
 	(when (nth 8 pps)
 	  (goto-char (nth 8 pps))
-	  
+
 	  t)
       (when all-comments
 	(prog1
@@ -581,6 +585,6 @@ If COUNT is negative, travel backward."
 
 ;;; matlab-syntax.el ends here
 
-;; LocalWords:  Ludlam eludlam compat booleanp propertize varname defmacro oldsyntax progn edebug
+;; LocalWords:  Ludlam eludlam compat booleanp propertize varname defmacro oldsyntax progn defface
 ;; LocalWords:  ppss sexp pps defun eobp mcm blockcomment EOL defconst commanddual cds bolp eol
-;; LocalWords:  cellbreak setq defsubst charvector memq sexps posn parens
+;; LocalWords:  cellbreak setq defsubst charvector memq sexps posn parens boundp gmail classdef's
